@@ -6,7 +6,7 @@ from .train import train_model, predict
 from .model import scaden
 
 def Deconvolution(necessary_data, real_bulk, sep='\t',
-                  datatype='counts', genelenfile=None,
+                  datatype='counts', genelenfile=None, d_prior=None,
                   mode='overall', adaptive=True,
                   save_model_name=None,
                   batch_size=128, epochs=128):
@@ -19,7 +19,9 @@ def Deconvolution(necessary_data, real_bulk, sep='\t',
     :param bulkDataType: FPKM or TPM, if type is RPKM, please just use FPKM
     :param genelenfile: specify the location of gene length file for transforming counts data to TPM or FPKM
                         this file should in txt format and
-                            contain three columns: [Gene name,Transcript start (bp),Transcript end (bp)]
+                        contain three columns: [Gene name,Transcript start (bp),Transcript end (bp)]
+    :param d_prior: prior knowledge about cell fractions, used to generate cell fractions, if this param is None, then the
+                    fractions is generated as a random way.
     :param mode: 'high-resolution' means this will apply adaptive stage to every single sample to generate signature matrix,
                  'overall' means that it will deconvolve all the samples at the same time
     :param adaptive: it has to be True, if model is 'high-resolution'
@@ -41,7 +43,7 @@ def Deconvolution(necessary_data, real_bulk, sep='\t',
     if type(necessary_data) is str:
         postfix = necessary_data.split('.')[-1]
         if postfix == 'txt':
-            simudata = generate_simulated_data(sc_data=necessary_data, samplenum=5000)
+            simudata = generate_simulated_data(sc_data=necessary_data, samplenum=5000, d_prior=d_prior)
 
         elif postfix == 'h5ad':
             simudata = anndata.read_h5ad(necessary_data)
@@ -52,7 +54,7 @@ def Deconvolution(necessary_data, real_bulk, sep='\t',
             raise Exception('Please give the correct input')
     else:
         if type(necessary_data) is pd.DataFrame:
-            simudata = generate_simulated_data(sc_data=necessary_data, samplenum=5000)
+            simudata = generate_simulated_data(sc_data=necessary_data, samplenum=5000, d_prior=d_prior)
 
         elif type(necessary_data) is anndata.AnnData:
             simudata = necessary_data
