@@ -5,7 +5,7 @@ from tqdm import tqdm
 from numpy.random import choice
 
 def generate_simulated_data(sc_data, outname=None,
-                            prop = None,
+                            d_prior=None,
                             n=500, samplenum=5000):
     # sc_data should be a cell*gene matrix, no null value, txt file, sep='\t'
     # index should be cell names
@@ -32,16 +32,17 @@ def generate_simulated_data(sc_data, outname=None,
     sc_data = sc_data.values
     sc_data = np.ascontiguousarray(sc_data, dtype=np.float32)
     # make random cell proportions
-    if prop is None:
-        print('Generating random cell fractions for each pseudo-bulk sample')
-        prop = np.random.rand(samplenum ,num_celltype)
-        prop = prop /np.sum(prop ,axis=1).reshape(-1 ,1)
 
-        for i in range(prop.shape[0]):
-            indices = np.random.choice(np.arange(prop.shape[1]), replace=False, size=int(prop.shape[1] * 0.3))
-            prop[i ,indices] = 0
-        prop = prop /np.sum(prop ,axis=1).reshape(-1 ,1)
-        print('Generating cell frations is done')
+    if d_prior is None:
+        print('Generating cell fractions using Dirichlet distribution without prior info (actually random)')
+        prop = np.random.dirichlet(np.ones(num_celltype),samplenum)
+        print('RANDOM cell fractions is generated')
+    elif d_prior is not None:
+        print('Using prior info to generate cell fractions in Dirichlet distribution')
+        assert len(d_prior) == num_celltype, 'dirichlet prior is a vector, its length should equals ' \
+                                             'to the number of cell types'
+        prop = np.random.dirichlet(d_prior, samplenum)
+        print('Dirichlet cell fractions is generated')
 
     # make the dictionary
     for key, value in celltype_groups.items():
